@@ -1,48 +1,55 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
     <name>EditShare</name>
     <message>
-        <location filename="editshare.ui" line="14"/>
+        <location filename="../editshare.ui" line="14"/>
         <source>Dialog</source>
         <translation>Dialogo</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="20"/>
+        <location filename="../editshare.ui" line="20"/>
         <source>&amp;Name</source>
         <translation>&amp;Nome</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="37"/>
+        <location filename="../editshare.ui" line="30"/>
+        <source>...</source>
+        <translation>...</translation>
+    </message>
+    <message>
+        <location filename="../editshare.ui" line="37"/>
         <source>&amp;Path</source>
         <translation>&amp;Percorso</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="51"/>
+        <location filename="../editshare.ui" line="51"/>
         <source>Yes</source>
         <translation>Sì</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="56"/>
+        <location filename="../editshare.ui" line="56"/>
         <source>No</source>
         <translation>No</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="64"/>
+        <location filename="../editshare.ui" line="64"/>
         <source>&amp;Comment</source>
         <translation>Commen&amp;to</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="77"/>
+        <location filename="../editshare.ui" line="77"/>
         <source>&amp;Guest OK</source>
         <translation>&amp;Ospite OK</translation>
     </message>
     <message>
-        <location filename="editshare.ui" line="111"/>
+        <location filename="../editshare.ui" line="111"/>
         <source>Access rights for valid users</source>
         <translation>Diritti d&apos;accesso per utenti validi</translation>
     </message>
     <message>
-        <location filename="editshare.cpp" line="49"/>
+        <location filename="../editshare.cpp" line="46"/>
         <source>Select directory to share</source>
         <translation>Seleziona la directory da condividere</translation>
     </message>
@@ -50,197 +57,195 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.ui" line="24"/>
+        <location filename="../mainwindow.ui" line="24"/>
         <source>&amp;Shares</source>
         <translation>&amp;Condivisioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="32"/>
+        <location filename="../mainwindow.ui" line="32"/>
         <source>Shares</source>
         <translation>Condivisioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="41"/>
+        <location filename="../mainwindow.ui" line="41"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nessun utente samba trovato&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="50"/>
-        <location filename="mainwindow.ui" line="157"/>
+        <location filename="../mainwindow.ui" line="50"/>
+        <location filename="../mainwindow.ui" line="157"/>
         <source>&amp;Remove</source>
         <translation>&amp;Rimuovi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="63"/>
-        <location filename="mainwindow.ui" line="164"/>
+        <location filename="../mainwindow.ui" line="63"/>
+        <location filename="../mainwindow.ui" line="164"/>
         <source>&amp;Add</source>
         <translation>A&amp;ggiungi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="70"/>
+        <location filename="../mainwindow.ui" line="70"/>
         <source>&amp;Edit</source>
         <translation>&amp;Modifica</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="80"/>
+        <location filename="../mainwindow.ui" line="80"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="85"/>
+        <location filename="../mainwindow.ui" line="85"/>
         <source>Path</source>
         <translation>Percorso</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="90"/>
+        <location filename="../mainwindow.ui" line="90"/>
         <source>Comment</source>
         <translation>Commento</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="95"/>
+        <location filename="../mainwindow.ui" line="95"/>
         <source>Permissions</source>
         <translation>Permessi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="100"/>
+        <location filename="../mainwindow.ui" line="100"/>
         <source>Guest OK</source>
         <translation>Ospite OK</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="142"/>
+        <location filename="../mainwindow.ui" line="142"/>
         <source>&amp;Users</source>
         <translation>&amp;Utenti</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="150"/>
+        <location filename="../mainwindow.ui" line="150"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nessun utente samba trovato&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="171"/>
+        <location filename="../mainwindow.ui" line="171"/>
         <source>&amp;Password</source>
         <translation>Pass&amp;word</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="194"/>
+        <location filename="../mainwindow.ui" line="194"/>
         <source>Users</source>
         <translation>Utenti</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="219"/>
-        <location filename="mainwindow.cpp" line="273"/>
-        <location filename="mainwindow.cpp" line="299"/>
+        <location filename="../mainwindow.ui" line="219"/>
+        <location filename="../mainwindow.cpp" line="311"/>
+        <location filename="../mainwindow.cpp" line="337"/>
         <source>E&amp;nable Automatic Samba Startup</source>
         <translation>Abilita avvio automatico di samba</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="226"/>
-        <location filename="mainwindow.cpp" line="252"/>
-        <location filename="mainwindow.cpp" line="308"/>
+        <location filename="../mainwindow.ui" line="226"/>
+        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="../mainwindow.cpp" line="346"/>
         <source>Star&amp;t Samba</source>
         <translation>A&amp;vvia samba</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="254"/>
+        <location filename="../mainwindow.ui" line="254"/>
         <source>Samba autostart service is disabled</source>
         <translation>Il servizio di avvio automatico di samba è disabilitato</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="285"/>
-        <location filename="mainwindow.cpp" line="250"/>
+        <location filename="../mainwindow.ui" line="285"/>
+        <location filename="../mainwindow.cpp" line="286"/>
         <source>Samba is running</source>
         <translation>Samba è in esecuzione</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="324"/>
+        <location filename="../mainwindow.ui" line="324"/>
         <source>About this application</source>
         <translation>Informazioni su questa applicazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="327"/>
+        <location filename="../mainwindow.ui" line="327"/>
         <source>A&amp;bout...</source>
         <translation>A propo&amp;sito di...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="334"/>
+        <location filename="../mainwindow.ui" line="334"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="366"/>
+        <location filename="../mainwindow.ui" line="366"/>
         <source>Display help </source>
         <translation>Visualizza la guida</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="369"/>
+        <location filename="../mainwindow.ui" line="369"/>
         <source>&amp;Help</source>
         <translation>A&amp;iuto</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="376"/>
+        <location filename="../mainwindow.ui" line="376"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="411"/>
+        <location filename="../mainwindow.ui" line="411"/>
         <source>Quit application</source>
         <translation> Chiudi applicazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="414"/>
+        <location filename="../mainwindow.ui" line="414"/>
         <source>&amp;Close</source>
         <translation>C&amp;hiudi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="421"/>
+        <location filename="../mainwindow.ui" line="421"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="79"/>
-        <location filename="mainwindow.cpp" line="83"/>
-        <location filename="mainwindow.cpp" line="106"/>
-        <location filename="mainwindow.cpp" line="119"/>
-        <location filename="mainwindow.cpp" line="176"/>
-        <location filename="mainwindow.cpp" line="238"/>
-        <location filename="mainwindow.cpp" line="256"/>
-        <location filename="mainwindow.cpp" line="345"/>
-        <location filename="mainwindow.cpp" line="372"/>
-        <location filename="mainwindow.cpp" line="376"/>
-        <location filename="mainwindow.cpp" line="381"/>
-        <location filename="mainwindow.cpp" line="386"/>
-        <location filename="mainwindow.cpp" line="416"/>
-        <location filename="mainwindow.cpp" line="422"/>
-        <location filename="mainwindow.cpp" line="436"/>
-        <location filename="mainwindow.cpp" line="446"/>
-        <location filename="mainwindow.cpp" line="477"/>
-        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="../mainwindow.cpp" line="94"/>
+        <location filename="../mainwindow.cpp" line="98"/>
+        <location filename="../mainwindow.cpp" line="127"/>
+        <location filename="../mainwindow.cpp" line="139"/>
+        <location filename="../mainwindow.cpp" line="209"/>
+        <location filename="../mainwindow.cpp" line="274"/>
+        <location filename="../mainwindow.cpp" line="292"/>
+        <location filename="../mainwindow.cpp" line="385"/>
+        <location filename="../mainwindow.cpp" line="412"/>
+        <location filename="../mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="422"/>
+        <location filename="../mainwindow.cpp" line="428"/>
+        <location filename="../mainwindow.cpp" line="458"/>
+        <location filename="../mainwindow.cpp" line="464"/>
+        <location filename="../mainwindow.cpp" line="478"/>
+        <location filename="../mainwindow.cpp" line="488"/>
+        <location filename="../mainwindow.cpp" line="520"/>
+        <location filename="../mainwindow.cpp" line="532"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="79"/>
+        <location filename="../mainwindow.cpp" line="94"/>
         <source>Error, could not add share. Empty share name</source>
         <translation>Errore, impossibile aggiungere condivisione. Nome condivisione vuoto</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="83"/>
+        <location filename="../mainwindow.cpp" line="99"/>
         <source>Path: %1 doesn&apos;t exist.</source>
         <translation>Percorso: %1 non esiste.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="86"/>
-        <location filename="mainwindow.cpp" line="135"/>
         <source>Everyone</source>
-        <translation>Tutti</translation>
+        <translation type="vanished">Tutti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="104"/>
+        <location filename="../mainwindow.cpp" line="124"/>
         <source>Yes</source>
         <translation>Sì</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="106"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>Could not add share. Error message:
 
 %1</source>
@@ -249,161 +254,161 @@
 %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="119"/>
+        <location filename="../mainwindow.cpp" line="139"/>
         <source>Error listing users</source>
         <translation>Errore nell&apos;elencare gli utenti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="144"/>
+        <location filename="../mainwindow.cpp" line="165"/>
         <source>&amp;Deny</source>
         <translation>N&amp;ega</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="175"/>
         <source>&amp;Read Only</source>
         <translation>Solo &amp;lettura</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="156"/>
+        <location filename="../mainwindow.cpp" line="185"/>
         <source>&amp;Full Access</source>
         <translation>&amp;Accesso completo</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="176"/>
+        <location filename="../mainwindow.cpp" line="209"/>
         <source>Error listing shares</source>
         <translation>Errore nell&apos;elencare le condivisioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="239"/>
+        <location filename="../mainwindow.cpp" line="275"/>
         <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
         <translation>Il tuo utente non appartiene al gruppo &quot;sambashare&quot;, se hai appena installato l&apos;applicazione potresti dover prima riavviare il sistema.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="249"/>
+        <location filename="../mainwindow.cpp" line="285"/>
         <source>Sto&amp;p Samba</source>
         <translation>&amp;Ferma samba</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="289"/>
         <source>Samba is not running</source>
         <translation>Samba non è in esecuzione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
+        <location filename="../mainwindow.cpp" line="292"/>
         <source>Samba not installed</source>
         <translation>Samba non installato</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="270"/>
+        <location filename="../mainwindow.cpp" line="308"/>
         <source>&amp;Disable Automatic Samba Startup</source>
         <translation>Disa&amp;bilita l&apos;avvio automatico di samba</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="321"/>
+        <location filename="../mainwindow.cpp" line="360"/>
         <source>About %1</source>
         <translation>Circa %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="321"/>
+        <location filename="../mainwindow.cpp" line="360"/>
         <source>MX Samba Config</source>
         <translation>MX Configurazione Samba</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="323"/>
+        <location filename="../mainwindow.cpp" line="361"/>
         <source>Version: </source>
         <translation>Versione: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="363"/>
         <source>Program for configuring Samba shares and users.</source>
         <translation>Programma per configurare le condivisioni e gli utenti samba.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="../mainwindow.cpp" line="365"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="327"/>
+        <location filename="../mainwindow.cpp" line="366"/>
         <source>%1 License</source>
         <translation>%1 Licenza</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="335"/>
+        <location filename="../mainwindow.cpp" line="373"/>
         <source>%1 Help</source>
         <translation>%1 Aiuto</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="385"/>
         <source>Cannot delete user: </source>
         <translation>Impossibile eliminare l&apos;utente:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="353"/>
+        <location filename="../mainwindow.cpp" line="393"/>
         <source>Enter the username and password:</source>
         <translation>Inserire il nome utente e la password:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="360"/>
+        <location filename="../mainwindow.cpp" line="400"/>
         <source>Username:</source>
         <translation>Nome utente:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="361"/>
-        <location filename="mainwindow.cpp" line="405"/>
+        <location filename="../mainwindow.cpp" line="401"/>
+        <location filename="../mainwindow.cpp" line="447"/>
         <source>Password:</source>
         <translation>Password:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="362"/>
-        <location filename="mainwindow.cpp" line="406"/>
+        <location filename="../mainwindow.cpp" line="402"/>
+        <location filename="../mainwindow.cpp" line="448"/>
         <source>Confirm password:</source>
         <translation>Conferma password:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="372"/>
+        <location filename="../mainwindow.cpp" line="412"/>
         <source>Empty username, please enter a name.</source>
         <translation>Nome utente vuoto, inserire un nome.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="376"/>
+        <location filename="../mainwindow.cpp" line="417"/>
         <source>Matching linux user not found on system, make sure you enter a valid username.</source>
         <translation>Utente Linux corrispondente non trovato sul sistema, assicurati di inserire un nome utente valido.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="381"/>
-        <location filename="mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="422"/>
+        <location filename="../mainwindow.cpp" line="458"/>
         <source>Passwords don&apos;t match, please enter again.</source>
         <translation>La password non corrisponde, inserirla di nuovo.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="386"/>
+        <location filename="../mainwindow.cpp" line="428"/>
         <source>Could not add user.</source>
         <translation>Impossibile aggiungere l&apos;utente.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="399"/>
+        <location filename="../mainwindow.cpp" line="441"/>
         <source>Change the password for &apos;%1&apos;</source>
         <translation>Cambiare la password per &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="422"/>
+        <location filename="../mainwindow.cpp" line="464"/>
         <source>Could not change password.</source>
         <translation>Impossibile cambiare la password.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="436"/>
+        <location filename="../mainwindow.cpp" line="478"/>
         <source>Cannot delete share: </source>
         <translation>Impossibile eliminare la condivisione:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="447"/>
-        <location filename="mainwindow.cpp" line="489"/>
+        <location filename="../mainwindow.cpp" line="489"/>
+        <location filename="../mainwindow.cpp" line="533"/>
         <source>Samba service is not running. Please start Samba before adding or editing shares</source>
         <translation>Il servizio samba non è in esecuzione. Avviare samba prima di aggiungere o modificare condivisioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="477"/>
+        <location filename="../mainwindow.cpp" line="520"/>
         <source>Error: trying to process permissions: </source>
         <translation>Errore: tentativo di elaborare i permessi:</translation>
     </message>
@@ -411,30 +416,53 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="about.cpp" line="58"/>
+        <source>License</source>
+        <translation type="vanished">Licenza</translation>
+    </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="vanished">Registro delle modifiche</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="vanished">Annulla</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="vanished">Chiu&amp;di</translation>
+    </message>
+    <message>
+        <source>You must run this program as normal user.</source>
+        <translation type="vanished">Devi eseguire questo programma come utente normale.</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="39"/>
         <source>License</source>
         <translation>Licenza</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="59"/>
-        <location filename="about.cpp" line="69"/>
+        <location filename="../about.cpp" line="40"/>
+        <location filename="../about.cpp" line="49"/>
         <source>Changelog</source>
         <translation>Registro delle modifiche</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="60"/>
+        <location filename="../about.cpp" line="41"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="81"/>
+        <location filename="../about.cpp" line="62"/>
         <source>&amp;Close</source>
-        <translation>Chiu&amp;di</translation>
+        <translation>&amp;Chiudi</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="61"/>
+        <location filename="../main.cpp" line="61"/>
         <source>You must run this program as normal user.</source>
         <translation>Devi eseguire questo programma come utente normale.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
